pub enum Error {
Path,
Git(Error),
// some variants omitted
}Expand description
Represents all the ways that GitClone can fail.
This type is not intended to be exhaustively matched, and new variants may be added in the future without a major version bump.
Variants
Path
The provided GitClone::path configuration is invalid.
Git(Error)
An error occurred while cloning the Git repository.